package Microsoft::AdCenter::V7::ReportingService::AdPerformanceReportColumn;
# Copyright (C) 2012 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

=head1 NAME

Microsoft::AdCenter::V7::ReportingService::AdPerformanceReportColumn - Represents "AdPerformanceReportColumn" in Microsoft AdCenter Reporting Service.

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=head1 ENUMERATION VALUES

    AccountName
    AccountNumber
    AdDescription
    AdDistribution
    AdGroupId
    AdGroupName
    AdId
    AdTitle
    AdType
    AverageCpc
    AverageCpm
    AveragePosition
    CampaignName
    Clicks
    ConversionRate
    Conversions
    CostPerConversion
    Ctr
    CurrencyCode
    DestinationUrl
    DeviceType
    DisplayUrl
    Impressions
    Language
    LanguageAndRegion
    PricingModel
    Spend
    TimePeriod

=cut

sub AccountName {
    return 'AccountName';
}

sub AccountNumber {
    return 'AccountNumber';
}

sub AdDescription {
    return 'AdDescription';
}

sub AdDistribution {
    return 'AdDistribution';
}

sub AdGroupId {
    return 'AdGroupId';
}

sub AdGroupName {
    return 'AdGroupName';
}

sub AdId {
    return 'AdId';
}

sub AdTitle {
    return 'AdTitle';
}

sub AdType {
    return 'AdType';
}

sub AverageCpc {
    return 'AverageCpc';
}

sub AverageCpm {
    return 'AverageCpm';
}

sub AveragePosition {
    return 'AveragePosition';
}

sub CampaignName {
    return 'CampaignName';
}

sub Clicks {
    return 'Clicks';
}

sub ConversionRate {
    return 'ConversionRate';
}

sub Conversions {
    return 'Conversions';
}

sub CostPerConversion {
    return 'CostPerConversion';
}

sub Ctr {
    return 'Ctr';
}

sub CurrencyCode {
    return 'CurrencyCode';
}

sub DestinationUrl {
    return 'DestinationUrl';
}

sub DeviceType {
    return 'DeviceType';
}

sub DisplayUrl {
    return 'DisplayUrl';
}

sub Impressions {
    return 'Impressions';
}

sub Language {
    return 'Language';
}

sub LanguageAndRegion {
    return 'LanguageAndRegion';
}

sub PricingModel {
    return 'PricingModel';
}

sub Spend {
    return 'Spend';
}

sub TimePeriod {
    return 'TimePeriod';
}

1;
